import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    noCache: true                if set true, the page will no be cached(default is false)
    affix: true                  if set true, the tag will affix in the tags-view
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/auth-redirect',
    component: () => import('@/views/login/auth-redirect'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/error-page/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error-page/401'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [
      {
        path: 'dashboard',
        component: () => import('@/views/dashboard/index'),
        name: 'Dashboard',
        meta: { title: '首页', icon: 'el-icon-s-home', noCache: true }
      }
    ]
  }
]

/**
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
export const asyncRoutes = [
  {
    path: '/program',
    component: Layout,
    redirect: '/program/index',
    alwaysShow: true,
    hidden: true,
    name: 'Program',
    meta: { title: '项目阶段--参考', icon: 'el-icon-menu', noCache: true },
    children: [
      {
        path: 'index',
        component: () => import('@/views/program/index'),
        name: 'Program',
        meta: { title: '拆补方案', icon: 'el-icon-s-grid', noCache: true }
      },
      {
        path: 'new',
        component: () => import('@/views/program/new/index'),
        name: 'ProgramNew',
        hidden: true,
        meta: { title: '新建拆补方案', noCache: true, activeMenu: '/program/index' }
      },
      {
        path: 'detail/:id',
        component: () => import('@/views/program/detail/index'),
        name: 'ProgramDetail',
        hidden: true,
        meta: { title: '拆补方案详情', noCache: true, activeMenu: '/program/index' }
      },
      {
        path: 'vote',
        component: () => import('@/views/program/vote/index'),
        name: 'Vote',
        hidden: true,
        meta: { title: '查看投票', noCache: true, activeMenu: '/program/index' }
      },
      {
        path: 'result',
        component: () => import('@/views/program/result/index'),
        name: 'Result',
        hidden: true,
        meta: { title: '查看结果', noCache: true, activeMenu: '/program/index' }
      }
    ]
  },
  {
    path: '/investigation',
    component: Layout,
    redirect: '/investigation/index',
    alwaysShow: true,
    name: 'Investigation',
    meta: { title: '现状调研阶段', icon: 'el-icon-office-building', noCache: true },
    children: [
      {
        path: 'index',
        component: () => import('@/views/investigation/index'),
        name: 'InvestigationIndex',
        meta: { title: '信息填报统计', noCache: true }
      },
      {
        path: 'neighborhood',
        component: () => import('@/views/investigation/neighborhood'),
        name: 'Neighborhood',
        hidden: true,
        meta: { title: '社区信息（居委会）', noCache: true, activeMenu: '/investigation/index' }
      },
      {
        path: 'resident',
        component: () => import('@/views/investigation/resident'),
        name: 'Resident',
        hidden: true,
        meta: { title: '居民填报信息', noCache: true, activeMenu: '/investigation/index' }
      },
      {
        path: 'policy',
        component: () => import('@/views/investigation/policy/index'),
        name: 'Policy',
        meta: { title: '重要政策文件', noCache: true }
      },
      {
        path: 'new',
        component: () => import('@/views/investigation/policy/new'),
        name: 'New',
        hidden: true,
        meta: { title: '重要政策文件新增', noCache: true, activeMenu: '/investigation/policy' }
      },
      {
        path: 'detail',
        component: () => import('@/views/investigation/policy/detail'),
        name: 'Detail',
        hidden: true,
        meta: { title: '重要政策文件详情', noCache: true, activeMenu: '/investigation/policy' }
      },
      {
        path: 'edit',
        component: () => import('@/views/investigation/policy/edit'),
        name: 'Edit',
        hidden: true,
        meta: { title: '重要政策文件编辑', noCache: true, activeMenu: '/investigation/policy' }
      }
    ]
  },
  {
    path: '/demand',
    component: Layout,
    redirect: '/demand/index',
    alwaysShow: true,
    name: 'Demand',
    meta: { title: '需求调查阶段', icon: 'el-icon-s-grid', noCache: true },
    children: [
      {
        path: 'index',
        component: () => import('@/views/demand/index'),
        name: 'QuestionIndex',
        meta: { title: '发起需求调查', noCache: true }
      },
      {
        path: 'question',
        component: () => import('@/views/demand/question/index'),
        name: 'quesiton',
        hidden: true,
        meta: { title: '基本问卷设计', noCache: true, activeMenu: '/demand/index' }
      },
      {
        path: 'basicDesign',
        component: () => import('@/views/demand/question/basicDesign'),
        name: 'BasicDesign',
        hidden: true,
        meta: { title: '基本需求设计', noCache: true, activeMenu: '/demand/index' }
      },
      {
        path: 'basicPlus',
        component: () => import('@/views/demand/question/basicPlus'),
        name: 'basicPlus',
        hidden: true,
        meta: { title: '新增基础类', noCache: true, activeMenu: '/demand/index' }
      },
      {
        path: 'perfectDesign',
        component: () => import('@/views/demand/question/perfectDesign'),
        name: 'PerfectDesign',
        hidden: true,
        meta: { title: '完善需求设计', noCache: true, activeMenu: '/demand/index' }
      },
      {
        path: 'improveDesign',
        component: () => import('@/views/demand/question/improveDesign'),
        name: 'ImproveDesign',
        hidden: true,
        meta: { title: '提升需求设计', noCache: true, activeMenu: '/demand/index' }
      }
    ]
  },
  // {
  //   path: '/plan',
  //   component: Layout,
  //   redirect: '/plan/index',
  //   alwaysShow: true,
  //   name: 'Plan',
  //   meta: { title: '规划设计阶段', icon: 'el-icon-office-building', noCache: true },
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/plan/index'),
  //       name: 'PlanIndex',
  //       meta: { title: '确定设计方案', noCache: true }
  //     },
  //     {
  //       path: 'planDetail',
  //       component: () => import('@/views/plan/planDetail'),
  //       name: 'PlanDetail',
  //       hidden: true,
  //       meta: { title: '设计方案详情', noCache: true, activeMenu: '/plan/index' }
  //     },
  //     {
  //       path: 'implement',
  //       component: () => import('@/views/plan/implement'),
  //       name: 'Implement',
  //       meta: { title: '确定实施方案', noCache: true }
  //     }
  //   ]
  // },
  {
    path: '/user',
    component: Layout,
    redirect: '/user/index',
    alwaysShow: true,
    name: 'User',
    meta: { title: '规划设计阶段', icon: 'el-icon-office-building', noCache: true },
    children: [
      {
        path: 'index',
        component: () => import('@/views/user/index'),
        name: 'UserIndex',
        meta: { title: '确定设计方案', noCache: true }
      },
      {
        path: 'userAlter',
        component: () => import('@/views/user/userAlter'),
        name: 'UserAlter',
        hidden: true,
        meta: { title: '设计方案详情', noCache: true, activeMenu: '/user/index' }
      },
      {
        path: 'configUser',
        component: () => import('@/views/user/configUser'),
        name: 'ConfigUser',
        meta: { title: '确定实施方案', noCache: true }
      }
    ]
  },
  {
    path: '/implement',
    component: Layout,
    redirect: '/implement/index',
    alwaysShow: true,
    name: 'Implement',
    meta: { title: '实施运营阶段', icon: 'el-icon-office-building', noCache: true },
    children: [
      {
        path: 'index',
        component: () => import('@/views/implement/index'),
        name: 'ImplementIndex',
        meta: { title: '进度更新', noCache: true }
      },
      // {
      //   path: 'operation',
      //   component: () => import('@/views/implement/operation/index'),
      //   name: 'Operation',
      //   hidden: true,
      //   meta: { title: '运营阶段', noCache: true, activeMenu: '/implement/index' }
      // },
      {
        path: 'implementDetail',
        component: () => import('@/views/implement/implementDetail'),
        name: 'ImplementDetail',
        hidden: true,
        meta: { title: '实施进度更新详情', noCache: true, activeMenu: '/implement/index' }
      },
      // {
      //   path: 'operationDetail',
      //   component: () => import('@/views/implement/operation/operationDetail'),
      //   name: 'OperationDetail',
      //   hidden: true,
      //   meta: { title: '运营进度更新详情', noCache: true, activeMenu: '/implement/index' }
      // },
      {
        path: 'feedback',
        component: () => import('@/views/implement/feedback/index'),
        name: 'Feedback',
        meta: { title: '意见反馈', noCache: true }
      },
      {
        path: 'feedbackOperate',
        component: () => import('@/views/implement/feedbackOperate'),
        name: 'FeedbackOperate',
        hidden: true,
        meta: { title: '运营阶段-意见反馈', noCache: true, activeMenu: '/implement/feedback' }
      },
      {
        path: 'replyOperate',
        component: () => import('@/views/implement/replyOperate'),
        name: 'ReplyOperate',
        hidden: true,
        meta: { title: '运营意见回复', noCache: true, activeMenu: '/implement/feedback' }
      },
      {
        path: 'reply',
        component: () => import('@/views/implement/reply'),
        name: 'Reply',
        hidden: true,
        meta: { title: '实施意见回复', noCache: true, activeMenu: '/implement/feedback' }
      }
    ]
  },
  {
    path: '/permission',
    component: Layout,
    redirect: '/permission/page',
    hidden: true,
    name: 'Permission',
    meta: {
      title: 'Permission',
      icon: 'lock',
      roles: ['admin', 'editor'] // you can set roles in root nav
    },
    children: [
      {
        path: 'page',
        component: () => import('@/views/permission/page'),
        name: 'PagePermission',
        meta: {
          title: 'Page Permission',
          roles: ['admin'] // or you can only set roles in sub nav
        }
      },
      {
        path: 'directive',
        component: () => import('@/views/permission/directive'),
        name: 'DirectivePermission',
        meta: {
          title: 'Directive Permission'
          // if do not set roles, means: this page does not require permission
        }
      },
      {
        path: 'role',
        component: () => import('@/views/permission/role'),
        name: 'RolePermission',
        meta: {
          title: 'Role Permission',
          roles: ['admin']
        }
      }
    ]
  },
  {
    path: '/error',
    component: Layout,
    redirect: 'noRedirect',
    name: 'ErrorPages',
    hidden: true,
    meta: {
      title: 'Error Pages',
      icon: '404'
    },
    children: [
      {
        path: '401',
        component: () => import('@/views/error-page/401'),
        name: 'Page401',
        meta: { title: '401', noCache: true }
      },
      {
        path: '404',
        component: () => import('@/views/error-page/404'),
        name: 'Page404',
        meta: { title: '404', noCache: true }
      }
    ]
  },
  {
    path: '/error-log',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'log',
        component: () => import('@/views/error-log/index'),
        name: 'ErrorLog',
        meta: { title: 'Error Log', icon: 'bug' }
      }
    ]
  },
  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
