import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    noCache: true                if set true, the page will no be cached(default is false)
    affix: true                  if set true, the tag will affix in the tags-view
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/auth-redirect',
    component: () => import('@/views/login/auth-redirect'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/error-page/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error-page/401'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/index',
    children: [
      {
        path: 'index',
        component: () => import('@/views/user/index'),
        name: 'UserIndex',
        meta: { title: '用户管理', icon: 'el-icon-user', noCache: true }
      },
      {
        path: 'userAlter',
        component: () => import('@/views/user/userAlter'),
        name: 'UserAlter',
        hidden: true,
        meta: { title: '用户详情', noCache: true, activeMenu: '/user/index' }
      },
      {
        path: 'config',
        component: () => import('@/views/user/configUser'),
        name: 'UserConfig',
        hidden: true,
        meta: { title: '用户配置', noCache: true, activeMenu: '/user/index' }
      },
      {
        path: 'adduser',
        component: () => import('@/views/user/addUser'),
        name: 'UserAdd',
        hidden: true,
        meta: { title: '添加用户', noCache: true, activeMenu: '/user/index' }
      }
    ]
  },
  {
    path: '/station',
    component: Layout,
    children: [
      {
        path: 'station',
        component: () => import('@/views/station/index'),
        name: 'StationIndex',
        meta: { title: '站点管理', icon: 'el-icon-menu', noCache: true }
      },
      {
        path: 'stationAlter',
        component: () => import('@/views/station/stationAlter'),
        name: 'StationAlter',
        hidden: true,
        meta: { title: '站点详情', noCache: true, activeMenu: '/station/index' }
      },
      {
        path: 'stationAdd',
        component: () => import('@/views/station/addStation'),
        name: 'StationAdd',
        hidden: true,
        meta: { title: '添加站点', noCache: true, activeMenu: '/station/index' }
      }
    ]
  }
]

/**
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
export const asyncRoutes = [
  // {
  //   path: '/program',
  //   component: Layout,
  //   redirect: '/program/index',
  //   alwaysShow: true,
  //   hidden: true,
  //   name: 'Program',
  //   meta: { title: '项目阶段--参考', icon: 'el-icon-menu', noCache: true },
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/program/index'),
  //       name: 'Program',
  //       meta: { title: '拆补方案', icon: 'el-icon-s-grid', noCache: true }
  //     },
  //     {
  //       path: 'new',
  //       component: () => import('@/views/program/new/index'),
  //       name: 'ProgramNew',
  //       hidden: true,
  //       meta: { title: '新建拆补方案', noCache: true, activeMenu: '/program/index' }
  //     },
  //     {
  //       path: 'detail/:id',
  //       component: () => import('@/views/program/detail/index'),
  //       name: 'ProgramDetail',
  //       hidden: true,
  //       meta: { title: '拆补方案详情', noCache: true, activeMenu: '/program/index' }
  //     },
  //     {
  //       path: 'vote',
  //       component: () => import('@/views/program/vote/index'),
  //       name: 'Vote',
  //       hidden: true,
  //       meta: { title: '查看投票', noCache: true, activeMenu: '/program/index' }
  //     },
  //     {
  //       path: 'result',
  //       component: () => import('@/views/program/result/index'),
  //       name: 'Result',
  //       hidden: true,
  //       meta: { title: '查看结果', noCache: true, activeMenu: '/program/index' }
  //     }
  //   ]
  // },
  // {
  //   path: '/user',
  //   component: Layout,
  //   redirect: '/user/index',
  //   alwaysShow: true,
  //   name: 'User',
  //   meta: { title: '用户管理', icon: 'el-icon-office-building', noCache: true },
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/user/index'),
  //       name: 'UserIndex',
  //       meta: { title: '用户列表', noCache: true }
  //     },
  //     {
  //       path: 'userAlter',
  //       component: () => import('@/views/user/userAlter'),
  //       name: 'UserAlter',
  //       hidden: true,
  //       meta: { title: '用户详情', noCache: true, activeMenu: '/user/index' }
  //     },
  //     {
  //       path: 'config',
  //       component: () => import('@/views/user/configUser'),
  //       name: 'UserConfig',
  //       hidden: true,
  //       meta: { title: '用户配置', noCache: true, activeMenu: '/user/index' }
  //     }
  //   ]
  // },
  // {
  //   path: '/station',
  //   component: Layout,
  //   redirect: '/station/index',
  //   alwaysShow: true,
  //   name: 'Station',
  //   meta: { title: '站点管理', icon: 'el-icon-office-building', noCache: true },
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/station/index'),
  //       name: 'StationIndex',
  //       meta: { title: '站点列表', noCache: true }
  //     },
  //     {
  //       path: 'userAlter',
  //       component: () => import('@/views/station/stationAlter'),
  //       name: 'StationAlter',
  //       hidden: true,
  //       meta: { title: '站点详情', noCache: true, activeMenu: '/station/index' }
  //     }
  //   ]
  // },
  {
    path: '/permission',
    component: Layout,
    redirect: '/permission/page',
    hidden: true,
    name: 'Permission',
    meta: {
      title: 'Permission',
      icon: 'lock',
      roles: ['admin', 'editor'] // you can set roles in root nav
    },
    children: [
      {
        path: 'page',
        component: () => import('@/views/permission/page'),
        name: 'PagePermission',
        meta: {
          title: 'Page Permission',
          roles: ['admin'] // or you can only set roles in sub nav
        }
      },
      {
        path: 'directive',
        component: () => import('@/views/permission/directive'),
        name: 'DirectivePermission',
        meta: {
          title: 'Directive Permission'
          // if do not set roles, means: this page does not require permission
        }
      },
      {
        path: 'role',
        component: () => import('@/views/permission/role'),
        name: 'RolePermission',
        meta: {
          title: 'Role Permission',
          roles: ['admin']
        }
      }
    ]
  },
  {
    path: '/error',
    component: Layout,
    redirect: 'noRedirect',
    name: 'ErrorPages',
    hidden: true,
    meta: {
      title: 'Error Pages',
      icon: '404'
    },
    children: [
      {
        path: '401',
        component: () => import('@/views/error-page/401'),
        name: 'Page401',
        meta: { title: '401', noCache: true }
      },
      {
        path: '404',
        component: () => import('@/views/error-page/404'),
        name: 'Page404',
        meta: { title: '404', noCache: true }
      }
    ]
  },
  {
    path: '/error-log',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'log',
        component: () => import('@/views/error-log/index'),
        name: 'ErrorLog',
        meta: { title: 'Error Log', icon: 'bug' }
      }
    ]
  },
  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
